@@ -27,6 +27,11 @@ static void  gail_pixmap_object_init    (GailPixmap      *pixmap);
 static void  atk_image_interface_init   (AtkImageIface  *iface);
 static G_CONST_RETURN gchar* gail_pixmap_get_image_description 
                                         (AtkImage       *obj);
+static void  gail_pixmap_get_image_position    
+                                        (AtkImage       *obj,
+                                         gint           *x,
+                                         gint           *y,
+                                         AtkCoordType   coord_type);
 static void  gail_pixmap_get_image_size (AtkImage       *obj,
                                          gint           *width,
                                          gint           *height);
@@ -115,6 +120,7 @@ atk_image_interface_init (AtkImageIface *iface)
   g_return_if_fail (iface != NULL);
 
   iface->get_image_description = gail_pixmap_get_image_description;
+  iface->get_image_position = gail_pixmap_get_image_position;
   iface->get_image_size = gail_pixmap_get_image_size;
   iface->set_image_description = gail_pixmap_set_image_description;
 }
@@ -131,6 +137,15 @@ gail_pixmap_get_image_description (AtkImage       *obj)
   return pixmap->image_description;
 }
 
+static void
+gail_pixmap_get_image_position (AtkImage       *obj,
+                                gint           *x,
+                                gint           *y,
+                                AtkCoordType   coord_type)
+{
+  atk_component_get_position (ATK_COMPONENT (obj), x, y, coord_type);
+}
+
 static void  
 gail_pixmap_get_image_size (AtkImage       *obj,
                             gint           *width,
